@@ -34,7 +34,7 @@ Google material colors L<http://www.google.com/design/spec/style/color.html>
 =cut
 
 package WebColors ;
-$WebColors::VERSION = '0.4.0';
+$WebColors::VERSION = '0.4.1';
 use 5.0.4 ;
 use warnings ;
 use strict ;
@@ -423,20 +423,20 @@ my %web_colors = (
     yellowa400 => [ 0xff, 0xea, 0x00 ],
     yellowa700 => [ 0xff, 0xd6, 0x00 ],
 
-    yellow50   => [ 0xff, 0xf8, 0xe1 ],
-    yellow100  => [ 0xff, 0xec, 0xb3 ],
-    yellow200  => [ 0xff, 0xe0, 0x82 ],
-    yellow300  => [ 0xff, 0xd5, 0x4f ],
-    yellow400  => [ 0xff, 0xca, 0x28 ],
-    yellow500  => [ 0xff, 0xc1, 0x07 ],
-    yellow600  => [ 0xff, 0xb3, 0x00 ],
-    yellow700  => [ 0xff, 0xa0, 0x00 ],
-    yellow800  => [ 0xff, 0x8f, 0x00 ],
-    yellow900  => [ 0xff, 0x6f, 0x00 ],
-    yellowa100 => [ 0xff, 0xe5, 0x7f ],
-    yellowa200 => [ 0xff, 0xd7, 0x40 ],
-    yellowa400 => [ 0xff, 0xc4, 0x00 ],
-    yellowa700 => [ 0xff, 0xab, 0x00 ],
+    amber50   => [ 0xff, 0xf8, 0xe1 ],
+    amber100  => [ 0xff, 0xec, 0xb3 ],
+    amber200  => [ 0xff, 0xe0, 0x82 ],
+    amber300  => [ 0xff, 0xd5, 0x4f ],
+    amber400  => [ 0xff, 0xca, 0x28 ],
+    amber500  => [ 0xff, 0xc1, 0x07 ],
+    amber600  => [ 0xff, 0xb3, 0x00 ],
+    amber700  => [ 0xff, 0xa0, 0x00 ],
+    amber800  => [ 0xff, 0x8f, 0x00 ],
+    amber900  => [ 0xff, 0x6f, 0x00 ],
+    ambera100 => [ 0xff, 0xe5, 0x7f ],
+    ambera200 => [ 0xff, 0xd7, 0x40 ],
+    ambera400 => [ 0xff, 0xc4, 0x00 ],
+    ambera700 => [ 0xff, 0xab, 0x00 ],
 
     orange50   => [ 0xff, 0xf3, 0xe0 ],
     orange100  => [ 0xff, 0xe0, 0xb2 ],
